@@ -42,8 +42,8 @@ Once = 3
 
 class DataListNode:
     def __init__(self):
-        self.key: AnyStr
-        self.data: AnyStr
+        self.key: AnyStr = ''
+        self.data: AnyStr = ''
         self.len = 0
         self.type = DataText
 
@@ -60,12 +60,12 @@ class DataListCls:
 
 
 class ResponseData:
-    def __init__(self):
-        self.key: AnyStr
-        self.data: AnyStr
-        self.len = 0
-        self.type = DataText
-        self.status = Once
+    def __init__(self, key='', data='', length=0, type=DataText, status=Once):
+        self.key = key
+        self.data = data
+        self.len = length
+        self.type = type
+        self.status = status
 
     def toJSON(self):
         return json.dumps(self, default=lambda o: o.__dict__,
@@ -74,17 +74,17 @@ class ResponseData:
 
 class Response:
     def __init__(self):
-        self.list: List[ResponseData]
-        self.errCode = 0
+        self.list: List[ResponseData] = [ResponseData()]
+        self.err_code = 0
+
+    def response_err(self, err_code: int):
+        self.err_code = err_code
+        return self
 
     def toJSON(self):
         return json.dumps(self, default=lambda o: o.__dict__,
             sort_keys=True, indent=4)
 
-    def response_err(self, errCode: int):
-        self.errCode = errCode
-        return self
-
 if __name__ == '__main__':
     t = Response()
     d = ResponseData()
